---
# https://vitepress.dev/reference/default-theme-home-page
layout: home
title: TurkiyeAPI
description: REST API for Turkey's administrative data

hero:
  name: 'TurkiyeAPI'
  text: "REST API for Turkey's administrative data"
  tagline: A comprehensive REST API providing detailed information about Turkey's administrative divisions including provinces, districts, neighborhoods and villages with demographic and geographical data.
  image:
    src: /logo.png
    alt: TurkiyeAPI Logo
  actions:
    - theme: brand
      text: Guide
      link: /en/v1/guide/welcome
    - theme: alt
      text: GitHub
      link: https://github.com/ubeydeozdmr/turkiye-api

features:
  - title: REST API
    details: TurkiyeAPI is designed to follow REST API standards.
  - title: Comprehensive Data Set
    details: Provides detailed information about many administrative divisions in Turkey.
  - title: Open Source
    details: TurkiyeAPI is an open-source project under the MIT license and is open to everyone.
  - title: Filtering, Sorting and Pagination
    details: TurkiyeAPI has filtering, sorting and pagination features.
---
